@@ -1,5 +1,5 @@
 ;; autoload.jl -- Initialise auto-load functions
-;; $Id: autoload.jl,v 1.14 2001/01/07 00:15:10 jsh Exp $
+;; $Id: autoload.jl,v 1.21 2002/08/18 21:30:05 jsh Exp $
 
 ;; Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -37,12 +37,12 @@
 (autoload-command (quote previous-workspace-window) (quote sawfish.wm.commands.cycle))
 (autoload-command (quote next-window) (quote sawfish.wm.commands.cycle))
 (autoload-command (quote previous-window) (quote sawfish.wm.commands.cycle))
-(autoload-command (quote describe-symbol) (quote sawfish.wm.commands.describe) #:user-level (quote expert))
-(autoload-command (quote describe-symbol-to-screen) (quote sawfish.wm.commands.describe) #:user-level (quote expert))
-(autoload-command (quote apropos-function) (quote sawfish.wm.commands.describe) #:user-level (quote expert))
-(autoload-command (quote apropos-function-to-screen) (quote sawfish.wm.commands.describe) #:user-level (quote expert))
-(autoload-command (quote apropos-variable) (quote sawfish.wm.commands.describe) #:user-level (quote expert))
-(autoload-command (quote apropos-variable-to-screen) (quote sawfish.wm.commands.describe) #:user-level (quote expert))
+(autoload-command (quote describe-symbol) (quote sawfish.wm.commands.describe) #:class 'default)
+(autoload-command (quote describe-symbol-to-screen) (quote sawfish.wm.commands.describe) #:class 'default)
+(autoload-command (quote apropos-function) (quote sawfish.wm.commands.describe) #:class 'default)
+(autoload-command (quote apropos-function-to-screen) (quote sawfish.wm.commands.describe) #:class 'default)
+(autoload-command (quote apropos-variable) (quote sawfish.wm.commands.describe) #:class 'default)
+(autoload-command (quote apropos-variable-to-screen) (quote sawfish.wm.commands.describe) #:class 'default)
 (autoload-command (quote gnome-toggle-skip-winlist) (quote sawfish.wm.commands.gnome))
 (autoload-command (quote gnome-set-skip-winlist) (quote sawfish.wm.commands.gnome))
 (autoload-command (quote gnome-clear-skip-winlist) (quote sawfish.wm.commands.gnome))
@@ -60,13 +60,13 @@
 (autoload-command (quote send-group-to-next-workspace) (quote sawfish.wm.commands.groups))
 (autoload-command (quote send-group-to-previous-workspace) (quote sawfish.wm.commands.groups))
 (autoload-command (quote move-group-to-current-viewport) (quote sawfish.wm.commands.groups))
-(autoload-command (quote move-group-left) (quote sawfish.wm.commands.groups))
-(autoload-command (quote move-group-right) (quote sawfish.wm.commands.groups))
-(autoload-command (quote move-group-up) (quote sawfish.wm.commands.groups))
-(autoload-command (quote move-group-down) (quote sawfish.wm.commands.groups))
-(autoload-command (quote raise-group) (quote sawfish.wm.commands.groups) #:user-level (quote expert))
-(autoload-command (quote lower-group) (quote sawfish.wm.commands.groups) #:user-level (quote expert))
-(autoload-command (quote raise-lower-group) (quote sawfish.wm.commands.groups) #:user-level (quote expert))
+(autoload-command (quote move-group-left) (quote sawfish.wm.commands.groups) #:class 'default)
+(autoload-command (quote move-group-right) (quote sawfish.wm.commands.groups) #:class 'default)
+(autoload-command (quote move-group-up) (quote sawfish.wm.commands.groups) #:class 'default)
+(autoload-command (quote move-group-down) (quote sawfish.wm.commands.groups) #:class 'default)
+(autoload-command (quote raise-group) (quote sawfish.wm.commands.groups) #:class 'default)
+(autoload-command (quote lower-group) (quote sawfish.wm.commands.groups) #:class 'default)
+(autoload-command (quote raise-lower-group) (quote sawfish.wm.commands.groups) #:class 'default)
 (autoload-command (quote raise-group-depth) (quote sawfish.wm.commands.groups))
 (autoload-command (quote lower-group-depth) (quote sawfish.wm.commands.groups))
 (autoload-command (quote delete-group) (quote sawfish.wm.commands.groups))
@@ -98,9 +98,9 @@
 (autoload-command (quote raise-and-pass-through-click) (quote sawfish.wm.commands.raise-commands))
 (autoload-command (quote raise-and-pass-through-click-if-focused) (quote sawfish.wm.commands.raise-commands))
 (autoload-command (quote raise-or-pass-through-click) (quote sawfish.wm.commands.raise-commands))
-(autoload-command (quote raise-window-and-pass-through-click) (quote sawfish.wm.commands.raise-commands) #:user-level (quote expert))
-(autoload-command (quote raise-group-and-pass-through-click) (quote sawfish.wm.commands.raise-commands) #:user-level (quote expert))
-(autoload-command (quote raise-transients-and-pass-through-click) (quote sawfish.wm.commands.raise-commands) #:user-level (quote expert))
+(autoload-command (quote raise-window-and-pass-through-click) (quote sawfish.wm.commands.raise-commands) #:class 'default)
+(autoload-command (quote raise-group-and-pass-through-click) (quote sawfish.wm.commands.raise-commands) #:class 'default)
+(autoload-command (quote raise-transients-and-pass-through-click) (quote sawfish.wm.commands.raise-commands) #:class 'default)
 (autoload-command (quote size-window-add-row) (quote sawfish.wm.commands.size-window))
 (autoload-command (quote size-window-subtract-row) (quote sawfish.wm.commands.size-window))
 (autoload-command (quote size-window-add-column) (quote sawfish.wm.commands.size-window))
@@ -113,44 +113,6 @@
 (autoload-command (quote slide-group-right) (quote sawfish.wm.commands.slide-window))
 (autoload-command (quote slide-group-up) (quote sawfish.wm.commands.slide-window))
 (autoload-command (quote slide-group-down) (quote sawfish.wm.commands.slide-window))
-(autoload-command (quote set-viewport-linear) (quote sawfish.wm.commands.viewport-linear) #:type (backquote (and (labelled (backquote-unquote (_ "Index:")) (number 0)))))
-(autoload-command (quote set-window-viewport-linear) (quote sawfish.wm.commands.viewport-linear) #:type (backquote (and (labelled (backquote-unquote (_ "Index:")) (number 0)))))
-(autoload-command 'set-viewport-linear:1 'sawfish.wm.commands.viewport-linear)
-(autoload-command 'set-window-viewport-linear:1 'sawfish.wm.commands.viewport-linear)
-(autoload-command 'set-viewport-linear:2 'sawfish.wm.commands.viewport-linear)
-(autoload-command 'set-window-viewport-linear:2 'sawfish.wm.commands.viewport-linear)
-(autoload-command 'set-viewport-linear:3 'sawfish.wm.commands.viewport-linear)
-(autoload-command 'set-window-viewport-linear:3 'sawfish.wm.commands.viewport-linear)
-(autoload-command 'set-viewport-linear:4 'sawfish.wm.commands.viewport-linear)
-(autoload-command 'set-window-viewport-linear:4 'sawfish.wm.commands.viewport-linear)
-(autoload-command 'set-viewport-linear:5 'sawfish.wm.commands.viewport-linear)
-(autoload-command 'set-window-viewport-linear:5 'sawfish.wm.commands.viewport-linear)
-(autoload-command 'set-viewport-linear:6 'sawfish.wm.commands.viewport-linear)
-(autoload-command 'set-window-viewport-linear:6 'sawfish.wm.commands.viewport-linear)
-(autoload-command 'set-viewport-linear:7 'sawfish.wm.commands.viewport-linear)
-(autoload-command 'set-window-viewport-linear:7 'sawfish.wm.commands.viewport-linear)
-(autoload-command 'set-viewport-linear:8 'sawfish.wm.commands.viewport-linear)
-(autoload-command 'set-window-viewport-linear:8 'sawfish.wm.commands.viewport-linear)
-(autoload-command 'set-viewport-linear:9 'sawfish.wm.commands.viewport-linear)
-(autoload-command 'set-window-viewport-linear:9 'sawfish.wm.commands.viewport-linear)
-(put 'set-viewport-linear:1 'deprecated-command t)
-(put 'set-window-viewport-linear:1 'deprecated-command t)
-(put 'set-viewport-linear:2 'deprecated-command t)
-(put 'set-window-viewport-linear:2 'deprecated-command t)
-(put 'set-viewport-linear:3 'deprecated-command t)
-(put 'set-window-viewport-linear:3 'deprecated-command t)
-(put 'set-viewport-linear:4 'deprecated-command t)
-(put 'set-window-viewport-linear:4 'deprecated-command t)
-(put 'set-viewport-linear:5 'deprecated-command t)
-(put 'set-window-viewport-linear:5 'deprecated-command t)
-(put 'set-viewport-linear:6 'deprecated-command t)
-(put 'set-window-viewport-linear:6 'deprecated-command t)
-(put 'set-viewport-linear:7 'deprecated-command t)
-(put 'set-window-viewport-linear:7 'deprecated-command t)
-(put 'set-viewport-linear:8 'deprecated-command t)
-(put 'set-window-viewport-linear:8 'deprecated-command t)
-(put 'set-viewport-linear:9 'deprecated-command t)
-(put 'set-window-viewport-linear:9 'deprecated-command t)
 (defgroup cycle "Window Cycling" :group focus :require sawfish.wm.commands.x-cycle)
 (autoload-command 'cycle-windows 'sawfish.wm.commands.x-cycle)
 (autoload-command 'cycle-windows-backwards 'sawfish.wm.commands.x-cycle)
@@ -160,18 +122,17 @@
 (autoload-command 'cycle-prefix-backwards 'sawfish.wm.commands.x-cycle)
 (autoload-command 'cycle-class 'sawfish.wm.commands.x-cycle)
 (autoload-command 'cycle-class-backwards 'sawfish.wm.commands.x-cycle)
+(autoload-command 'cycle-dock 'sawfish.wm.commands.x-cycle)
+(autoload-command 'cycle-dock-backwards 'sawfish.wm.commands.x-cycle)
 (autoload-command (quote xterm) (quote sawfish.wm.commands.xterm))
-(autoload-command (quote 3d-hack) (quote sawfish.wm.ext.3d-hack) #:user-level (quote expert))
+(autoload-command (quote 3d-hack) (quote sawfish.wm.ext.3d-hack) #:class 'default)
 (defgroup audio "Sound" :require sawfish.wm.ext.audio-events)
-(defgroup edge-flip "Edge Flipping" :group workspace :require sawfish.wm.ext.edge-flip)
 (defgroup match-window "Matched Windows" :layout single :require sawfish.wm.ext.match-window)
-(defgroup shade-hover "Shade Hover" :group focus :require sawfish.wm.ext.shade-hover)
 (defgroup tooltips "Tooltips" :group misc :require sawfish.wm.ext.tooltips)
-(autoload-placement-mode 'first-fit 'sawfish.wm.placement.smart)
-(autoload-placement-mode 'best-fit 'sawfish.wm.placement.smart)
-(autoload-placement-mode 'best-fit-group 'sawfish.wm.placement.smart)
-(autoload-placement-mode 'first-fit-or-interactive 'sawfish.wm.placement.smart)
-(autoload-placement-mode 'stagger 'sawfish.wm.placement.stagger)
+(autoload-placement-mode 'first-fit 'sawfish.wm.placement.smart #:for-normal t)
+(autoload-placement-mode 'best-fit 'sawfish.wm.placement.smart #:for-normal t)
+(autoload-placement-mode 'best-fit-group 'sawfish.wm.placement.smart #:for-normal t)
+(autoload-placement-mode 'first-fit-or-interactive 'sawfish.wm.placement.smart #:for-normal t)
 (autoload-command (quote maximize-window) (quote sawfish.wm.state.maximize))
 (autoload-command (quote unmaximize-window) (quote sawfish.wm.state.maximize))
 (autoload-command (quote maximize-window-vertically) (quote sawfish.wm.state.maximize))
@@ -188,10 +149,39 @@
 (autoload-command (quote describe-key) (quote sawfish.wm.util.keymap))
 (autoload-command (quote describe-key-to-screen) (quote sawfish.wm.util.keymap))
 (autoload-command (quote quote-event) (quote sawfish.wm.util.keymap))
-(autoload-command (quote move-viewport-next) (quote sawfish.wm.commands.viewport-extras))
-(autoload-command (quote move-viewport-previous) (quote sawfish.wm.commands.viewport-extras))
-(autoload-command (quote move-window-previous) (quote sawfish.wm.commands.viewport-extras))
-(autoload-command (quote move-window-next) (quote sawfish.wm.commands.viewport-extras))
-(autoload-placement-mode 'top-left 'sawfish.wm.placement.top-left)
-(autoload-placement-mode 'off-center 'sawfish.wm.placement.off-center)
+(autoload-placement-mode 'top-left 'sawfish.wm.placement.top-left #:for-normal t)
+(autoload-placement-mode 'stagger 'sawfish.wm.placement.stagger #:for-normal t)
+(autoload-placement-mode 'off-center 'sawfish.wm.placement.off-center #:for-normal t)
+(autoload-command (quote set-viewport-linear) (quote "viewport-linear") #:type (backquote (and (labelled (backquote-unquote (_ "Index:")) (number 0)))) #:class 'default)
+(autoload-command (quote set-window-viewport-linear) (quote "viewport-linear") #:type (backquote (and (labelled (backquote-unquote (_ "Index:")) (number 0)))) #:class 'default)
+(autoload-command 'set-viewport-linear:1 'sawfish.wm.commands.viewport-linear #:class 'default)
+(autoload-command 'set-window-viewport-linear:1 'sawfish.wm.commands.viewport-linear #:class 'default)
+(autoload-command 'set-viewport-linear:2 'sawfish.wm.commands.viewport-linear #:class 'default)
+(autoload-command 'set-window-viewport-linear:2 'sawfish.wm.commands.viewport-linear #:class 'default)
+(autoload-command 'set-viewport-linear:3 'sawfish.wm.commands.viewport-linear #:class 'default)
+(autoload-command 'set-window-viewport-linear:3 'sawfish.wm.commands.viewport-linear #:class 'default)
+(autoload-command 'set-viewport-linear:4 'sawfish.wm.commands.viewport-linear #:class 'default)
+(autoload-command 'set-window-viewport-linear:4 'sawfish.wm.commands.viewport-linear #:class 'default)
+(autoload-command 'set-viewport-linear:5 'sawfish.wm.commands.viewport-linear #:class 'default)
+(autoload-command 'set-window-viewport-linear:5 'sawfish.wm.commands.viewport-linear #:class 'default)
+(autoload-command 'set-viewport-linear:6 'sawfish.wm.commands.viewport-linear #:class 'default)
+(autoload-command 'set-window-viewport-linear:6 'sawfish.wm.commands.viewport-linear #:class 'default)
+(autoload-command 'set-viewport-linear:7 'sawfish.wm.commands.viewport-linear #:class 'default)
+(autoload-command 'set-window-viewport-linear:7 'sawfish.wm.commands.viewport-linear #:class 'default)
+(autoload-command 'set-viewport-linear:8 'sawfish.wm.commands.viewport-linear #:class 'default)
+(autoload-command 'set-window-viewport-linear:8 'sawfish.wm.commands.viewport-linear #:class 'default)
+(autoload-command 'set-viewport-linear:9 'sawfish.wm.commands.viewport-linear #:class 'default)
+(autoload-command 'set-window-viewport-linear:9 'sawfish.wm.commands.viewport-linear #:class 'default)
+(autoload-command (quote move-viewport-next) (quote sawfish.wm.commands.viewport-extras) #:class 'default)
+(autoload-command (quote move-viewport-previous) (quote sawfish.wm.commands.viewport-extras) #:class 'default)
+(autoload-command (quote move-window-previous) (quote sawfish.wm.commands.viewport-extras) #:class 'default)
+(autoload-command (quote move-window-next) (quote sawfish.wm.commands.viewport-extras) #:class 'default)
+(autoload-command (quote workspace-down) (quote sawfish.wm.ext.workspace-grid))
+(autoload-command (quote workspace-up) (quote sawfish.wm.ext.workspace-grid))
+(autoload-command (quote workspace-left) (quote sawfish.wm.ext.workspace-grid))
+(autoload-command (quote workspace-right) (quote sawfish.wm.ext.workspace-grid))
+(autoload-command (quote send-to-workspace-down) (quote sawfish.wm.ext.workspace-grid))
+(autoload-command (quote send-to-workspace-up) (quote sawfish.wm.ext.workspace-grid))
+(autoload-command (quote send-to-workspace-left) (quote sawfish.wm.ext.workspace-grid))
+(autoload-command (quote send-to-workspace-right) (quote sawfish.wm.ext.workspace-grid))
 ;;; ::autoload-end::
