@@ -1,5 +1,5 @@
 ;; audio-events.jl -- map wm actions to audio samples
-;; $Id: audio-events.jl,v 1.12 2001/01/08 00:37:28 jsh Exp $
+;; $Id: audio-events.jl,v 1.14 2002/04/21 03:39:34 jsh Exp $
 
 ;; Copyright (C) 2000 John Harper <john@dcs.warwick.ac.uk>
 
@@ -41,15 +41,11 @@
   (defcustom audio-events-enabled nil
     "Play sound effects for window events."
     :type boolean
-    :user-level novice
     :require sawfish.wm.ext.audio-events
     :group audio)
 
-  (defcustom audio-for-ignored-windows nil
-    "Play sound effects for unmanaged windows."
-    :type boolean
-    :depends audio-events-enabled
-    :group audio)
+  (defvar audio-for-ignored-windows nil
+    "Play sound effects for unmanaged windows.")
 
   ;; standard events are: iconified, uniconified, shaded, unshaded,
   ;; maximized, unmaximized, mapped, unmapped, mapped-transient,
