@@ -1,5 +1,5 @@
 ;; frames.jl -- handle window framing
-;; $Id: frames.jl,v 1.91 2002/10/20 08:07:50 jsh Exp $
+;; $Id: frames.jl,v 1.93 2003/10/21 16:17:59 jsh Exp $
 
 ;; Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -112,7 +112,6 @@
   ;; non-maximized. (In fact the frame-type != window-type scheme is
   ;; largely just for compatibility)
 
-
 ;;; custom support
 
   (define (custom-make-frame-style-widget)
@@ -120,7 +119,6 @@
 
   (put 'frame-style 'custom-widget custom-make-frame-style-widget)
 
-
 ;;; variables etc
 
   (defvar frame-part-classes nil
@@ -154,9 +152,12 @@ that overrides settings set elsewhere.")
       (shaded-transient . shaped-transient)
       (icon . shaped-transient)
       (dock . icon)
-      (utility . transient)
-      (toolbar . utility)
-      (menu . utility)
+      (utility . default)
+      (shaded-utility . shaded-transient)
+      (toolbar . unframed)
+;;    (shaded-toolbar . shaded-utility)
+      (menu . unframed)
+;;    (shaded-menu . shaded-utility)
       (splash . unframed))
     "Frame type fallbacks.")
 
@@ -204,7 +205,6 @@ deciding which frame type to ask a theme to generate.")
 
   (defvar sawfish-themer-program "sawfish-themer")
 
-
 ;;; defcustom's for some built-in variables
 
   (defcustom default-font nil
@@ -217,7 +217,6 @@ deciding which frame type to ask a theme to generate.")
   (defvar default-bevel-percent nil
     "Bevel intensity as a percentage.")
 
-
 ;;; managing frame types
 
   (define (define-frame-type-mapper fun)
@@ -244,7 +243,6 @@ deciding which frame type to ask a theme to generate.")
 	;; else, apply this transformation and keep looping
 	(loop-1 (cdr rest) ((car rest) w type)))))
 
-
 ;;; managing frame styles
 
   (define (add-frame-style name function)
@@ -289,7 +287,6 @@ deciding which frame type to ask a theme to generate.")
 		  (reload-frame-style style))))
 	    frame-style-files)))
 
-
 ;;; applying frame styles to windows
 
   (define (reframe-window w)
@@ -351,7 +348,6 @@ deciding which frame type to ask a theme to generate.")
     (when (apply-frame-style style)
       (save-current-frame-style)))
 
-
 ;;; editable frame styles
 
   (define (mark-frame-style-editable style)
@@ -369,7 +365,6 @@ deciding which frame type to ask a theme to generate.")
 	    (system (format nil "%s %s &" sawfish-themer-program dir))))))
     #:spec (lambda () (list default-frame-style)))
 
-
 ;;; kludge different window decors by modifying the assumed window type
 
   (define (window-type w)
@@ -441,7 +436,6 @@ deciding which frame type to ask a theme to generate.")
 	    (lambda (w) (set-window-type w type)) #:spec "%W"))
 	'(default transient shaped shaped-transient unframed))
 
-
 ;;; loading ``themes'' (currently just frame styles)
 
   (define (frame-style-directory dir #!optional get-name)
@@ -538,7 +532,6 @@ deciding which frame type to ask a theme to generate.")
        (check . ,(eq (window-type w) 'unframed))
        (group . menu-type))))
 
-
 ;;; removing frame parts
 
   (define (remove-frame-class w class)
@@ -556,7 +549,6 @@ deciding which frame type to ask a theme to generate.")
   (define (frame-class-removed-p w class)
     (memq class (window-get w 'removed-classes)))
 
-
 ;;; manipulating the frame part classes variables
 
   (define (set-frame-part-value class key value #!optional override)
@@ -622,7 +614,6 @@ deciding which frame type to ask a theme to generate.")
 	  ((bottom-right-corner) 'bottom_right_corner))
       nil))
 
-
 ;;; initialisation
 
   (define-frame-class 'menu-button '((keymap . menu-button-keymap)))
