@@ -1,5 +1,5 @@
 ;; menus.jl -- popup menus
-;; $Id: menus.jl,v 1.71 2001/06/18 18:36:50 jsh Exp $
+;; $Id: menus.jl,v 1.76 2005/02/07 00:12:18 jsh Exp $
 
 ;; Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -51,11 +51,8 @@
   ;; Suppress annoying compiler warnings
   (eval-when-compile (require 'rep.io.timers))
 
-  (defcustom menus-include-shortcuts nil
-    "Display key-binding information in menu items."
-    :type boolean
-    :group misc
-    :user-level expert)
+  (defvar menus-include-shortcuts nil
+    "Display key-binding information in menu items.")
 
   (defvar menu-program (expand-file-name "sawfish-menu" sawfish-exec-directory)
     "Location of the program implementing sawfish's menu interface.")
@@ -86,16 +83,18 @@ before killing it.")
   (define menu-timer nil)
 
   (defvar window-ops-menu
-    `((,(_ "Minimize") iconify-window
+    `((,(_ "Mi_nimize") iconify-window
        (insensitive . ,(lambda (w)
-			 (not (window-iconifiable-p w)))))
+                         (not (window-iconifiable-p w)))))
       (,(lambda (w)
-	  (if (window-maximized-p w)
-	      (_ "Unmaximize")
-	    (_ "Maximize"))) maximize-window-toggle
-       (insensitive . ,(lambda (w)
-			 (not (or (window-maximized-p w)
-				  (window-maximizable-p w))))))
+          (if (window-maximized-p w)
+              (_ "Unma_ximize")
+            (_ "Ma_ximize"))) maximize-window-toggle
+            (insensitive . ,(lambda (w)
+                              (not (or (window-maximized-p w)
+                                       (window-maximizable-p w))))))
+      (,(_ "_Move") move-window-interactively)
+      (,(_ "_Resize") resize-window-interactively)
       (,(_ "_Close") delete-window)
       ()
       (,(_ "_Toggle") . window-ops-toggle-menu)
@@ -103,20 +102,15 @@ before killing it.")
       (,(_ "_Send window to")
        (,(_ "_Previous workspace") send-to-previous-workspace)
        (,(_ "_Next workspace") send-to-next-workspace)
-       (,(_ "Copy to previous") copy-to-previous-workspace)
-       (,(_ "Copy to next") copy-to-next-workspace)
-       ()
-       (,(_ "_Left") move-window-left)
-       (,(_ "_Right") move-window-right)
-       (,(_ "_Up") move-window-up)
-       (,(_ "_Down") move-window-down))
-      (,(_ "Stacking")
-       (,(_ "Raise") raise-window)
-       (,(_ "Lower") lower-window)
-       (,(_ "Upper layer") raise-window-depth)
-       (,(_ "Lower layer") lower-window-depth))
-      (,(_ "Frame type") . frame-type-menu)
-      (,(_ "Frame style") . frame-style-menu)))
+       (,(_ "Copy to p_revious") copy-to-previous-workspace)
+       (,(_ "Copy to ne_xt") copy-to-next-workspace))
+      (,(_ "Stac_king")
+       (,(_ "_Raise") raise-window)
+       (,(_ "_Lower") lower-window)
+       (,(_ "_Upper layer") raise-window-depth)
+       (,(_ "Lo_wer layer") lower-window-depth))
+      (,(_ "Frame ty_pe") . frame-type-menu)
+      (,(_ "Frame sty_le") . frame-style-menu)))
 
   (defvar window-ops-toggle-menu '())
 
@@ -134,8 +128,8 @@ before killing it.")
        (,(_ "_Manual...") help:show-programmer-manual)
        (,(_ "_About Sawfish...") help:about))
       ()
-      (,(_ "Restart") restart)
-      (,(_ "Quit") quit)))
+      (,(_ "_Restart") restart)
+      (,(_ "_Quit") quit)))
 
   (defvar apps-menu
     `(("xterm" (system "xterm &"))
@@ -152,7 +146,8 @@ before killing it.")
       (setq menu-timer nil))
     (unless (and menu-process (process-in-use-p menu-process))
       (when menu-process
-	(kill-process menu-process))
+	(kill-process menu-process)
+	(setq menu-process nil))
       (let ((menu-sentinel (lambda ()
 			     (when (and menu-process
 					(not (process-in-use-p menu-process)))
@@ -186,8 +181,9 @@ before killing it.")
 	     ;; number of seconds to let it hang around for
 	     (require 'rep.io.timers)
 	     (setq menu-timer (make-timer (lambda ()
-					    (kill-process menu-process)
-					    (setq menu-process nil)
+					    (when menu-process
+					      (kill-process menu-process)
+					      (setq menu-process nil))
 					    (setq menu-timer nil))
 					  menu-program-stays-running)))
 	    ((or force (not menu-program-stays-running))
@@ -289,7 +285,7 @@ before killing it.")
 	      ;; to succeed)
 	      (ungrab-pointer)
 	      (ungrab-keyboard)
-	      (sync-server)
+	      (sync-server t)
 	      (when (functionp spec)
 		(setq spec (spec)))
 	      ;; XXX this is a hack, but I want menus to appear under buttons
@@ -355,7 +351,7 @@ before killing it.")
 
   (define (custom-menu)
     `(,@(and custom-menu-includes-all-settings
-	     (list (list (_ "All settings") 'customize) nil))
+	     (list (list (_ "_All settings") 'customize) nil))
       ,@(mapcar (lambda (sub)
 		  (list (_ (cadr sub))
 			(intern (concat "customize:"
