@@ -1,5 +1,5 @@
 ;; stacking.jl -- window stacking
-;; $Id: stacking.jl,v 1.53 2000/11/27 18:17:16 jsh Exp $
+;; $Id: stacking.jl,v 1.59 2002/10/18 06:46:16 jsh Exp $
 
 ;; Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -23,12 +23,15 @@
 
     (export save-stacking-order
 	    mapped-stacking-order
+            window-obscured
+            stacking-visibility
 	    raise-window
 	    lower-window
 	    stack-window-above
 	    stack-window-below
 	    restack-window
 	    stacking-order-by-depth
+	    window-depth
 	    set-window-depth
 	    window-on-top-p
 	    raise-lower-window
@@ -45,17 +48,19 @@
 	  sawfish.wm.custom
 	  sawfish.wm.session.init
 	  sawfish.wm.workspace
-	  sawfish.wm.state.transient)
+         sawfish.wm.state.transient
+          sawfish.wm.util.rects)
 
   ;; Each window will have a `depth' property--an integer, zero
   ;; represents the level of normal windows, negative for windows below
   ;; this level, and positive for windows above the normal level
 
+  (defgroup stacking "Stacking" :group misc)
+
   (defcustom transients-above 'parents
     "Keep transient windows stacked above: \\w"
-    :group misc
-    :type (choice all parents none)
-    :user-level expert)
+    :group (misc stacking)
+    :type (choice all parents none))
 
   (defmacro save-stacking-order (#!rest forms)
     "Execute FORMS, then reinstall the original stacking order."
@@ -65,22 +70,32 @@
 	     (progn ,@forms)
 	   (restack-windows ,tem)))))
 
-
+  ;; this will always return an integer
+  (define (window-depth w) (window-get w 'depth))
+
 ;;; constraint mechanics (predicates actually..)
 
   (define (stacking-constraint:layer w)
-    (let ((depth (window-get w 'depth)))
+    (let ((depth (window-depth w)))
       (lambda (above below)
 	;; constraints are met locally in ABOVE and BELOW, so just
 	;; test against windows adjacent to W
 	(and (or (null above)
-		 (<= depth (window-get (car above) 'depth)))
+		 (<= depth (window-depth (car above))))
 	     (or (null below)
-		 (>= depth (window-get (car below) 'depth)))))))
+		 (>= depth (window-depth (car below))))))))
 
   (define (stacking-constraint:transients-above-parent w)
     (let ((parents (transient-parents w))
 	  (children (transient-children w)))
+
+      ;; ignore parents with depth > W, ignore children with depth < W
+      (let ((w-depth (window-depth w)))
+	(setq parents (delete-if (lambda (x)
+				   (> (window-depth x) w-depth)) parents))
+	(setq children (delete-if (lambda (x)
+				    (< (window-depth x) w-depth)) children)))
+				 
       (lambda (above below)
 	(and (or (null parents)
 		 ;; All parents must be below W
@@ -96,21 +111,25 @@
 			 (t (loop (cdr rest))))))))))
 
   (define (stacking-constraint:transients-above-all w)
-    (if (window-transient-p w)
-	;; ensure there are no normal windows above W
+    (let ((w-depth (window-depth w)))
+      (if (window-transient-p w)
+	  ;; ensure there are no normal windows above W, unless they
+	  ;; have depth > W
+	  (lambda (above below)
+	    (declare (unused below))
+	    (let loop ((rest above))
+	      (cond ((null rest) t)
+		    ((and (not (window-transient-p (car rest)))
+			  (<= (window-depth (car rest)) w-depth)) nil)
+		    (t (loop (cdr rest))))))
+	;; ensure no transients below W, unless they're depth < W
 	(lambda (above below)
-	  (declare (unused below))
-	  (let loop ((rest above))
+	  (declare (unused above))
+	  (let loop ((rest below))
 	    (cond ((null rest) t)
-		  ((not (window-transient-p (car rest))) nil)
-		  (t (loop (cdr rest))))))
-      ;; ensure no transients below W
-      (lambda (above below)
-	(declare (unused above))
-	(let loop ((rest below))
-	  (cond ((null rest) t)
-		((window-transient-p (car rest)) nil)
-		(t (loop (cdr rest))))))))
+		  ((and (window-transient-p (car rest))
+			(>= (window-depth (car rest)) w-depth)) nil)
+		  (t (loop (cdr rest)))))))))
 
   (define (combine-constraints constraints)
     "Combine the list of secondary constraint functions into a single
@@ -141,7 +160,6 @@ for a particular stacking configuration, it will return non-`nil'."
 		      basic-stacking-constraints))
 	       (t basic-stacking-constraints)))))
 
-
 ;;; utilities
 
   ;; returns (BEFORE . AFTER), modifies LST
@@ -191,7 +209,54 @@ the empty list."
   (define (mapped-stacking-order)
     (delete-if-not window-mapped-p (stacking-order)))
 
-
+  (define (window-obscured window)
+    "Check whether WINDOW is obscured.  Return `t' if WINDOW is fully obscured
+by some other window, otherwise a list of windows partially obscuring WINDOW.
+In particular return `nil' if WINDOW is unobscured.  Note that if a list of
+partially obscuring windows is returned, taken together they may or may not
+fully obscure WINDOW."
+    (define w window)
+    (define ws (nearest-workspace-with-window w current-workspace))
+    (let loop ((stack (stacking-order))
+               (obs nil))
+         (if (null stack)               ; Should not happen
+             obs
+           (let ((w2 (car stack)))
+             (cond ((eq w2 w) obs)
+                   ((and (window-visible-p w2)
+                         (window-appears-in-workspace-p w2 ws))
+                    (case (apply rect-obscured
+                                 (rectangles-from-windows (list w w2)))
+                      ((unobscured) (loop (cdr stack) obs))
+                      ((fully-obscured) t)
+                      (t (loop (cdr stack) (cons w2 obs))))) ; Partially
+                   (t (loop (cdr stack) obs)))))))
+
+  (define (stacking-visibility window)
+    "Compute the visibility of WINDOW from the stacking order.  This should
+work even with the Composite extension, which appears to disable
+VisibilityNotify events.  Note that deciding between fully and partially
+obscured may require quite a bit of computation.  If you do not need that
+distinction, window-obscured should be faster."
+    (define (rect-list-minus rs s tail)
+      (if (null rs)
+          tail
+        (rect-list-minus (cdr rs) s
+                         (rect-minus (car rs) s tail))))
+    (let ((obs (window-obscured window)))
+      (case obs
+        ((t) 'fully-obscured)
+        ((()) 'unobscured)
+        (t
+         (do ((unobs (rectangles-from-windows (list window))
+                     (rect-list-minus unobs (car robs) nil))
+              (robs (rectangles-from-windows obs) (cdr robs)))
+             ((or (null unobs) (null robs))
+              (if (null unobs)
+                  'fully-obscured
+                'partially-obscured)))))))
+
+
 ;;; stacking functions
 
   (define (raise-window w)
@@ -285,11 +350,11 @@ window W as appropriate."
 order they are stacked within the layer (top to bottom)."
     (let ((order (stacking-order)))
       (delete-if (lambda (x)
-		   (/= (window-get x 'depth) depth)) order)))
+		   (/= (window-depth x) depth)) order)))
 
   (define (set-window-depth w depth)
     "Set the stacking depth of window W to DEPTH."
-    (let ((old (window-get w 'depth)))
+    (let ((old (window-depth w)))
       (window-put w 'depth depth)
       (cond ((> old depth)
 	     ;; window's going downwards
@@ -323,29 +388,28 @@ order they are stacked within the layer (top to bottom)."
   (define (raise-lower-window w)
     "If the window is at its highest possible position, then lower it to its
 lowest possible position. Otherwise raise it as far as allowed."
-    (if (or (eq (window-visibility w) 'unobscured)
+    (if (or (not (window-obscured w))
 	    (window-on-top-p w))
 	(lower-window w)
       (raise-window w)))
 
   (define (lower-window-depth w)
     "Put the window in the stacking level beneath its current level."
-    (set-window-depth w (1- (window-get w 'depth))))
+    (set-window-depth w (1- (window-depth w))))
 
   (define (raise-window-depth w)
     "Put the window in the stacking level above its current level."
-    (set-window-depth w (1+ (window-get w 'depth))))
+    (set-window-depth w (1+ (window-depth w))))
 
   (define-command 'raise-single-window raise-window
-    #:spec "%W" #:user-level 'expert)
+    #:spec "%W" #:class 'advanced)
   (define-command 'lower-single-window lower-window
-    #:spec "%W" #:user-level 'expert)
+    #:spec "%W" #:class 'advanced)
   (define-command 'raise-lower-single-window raise-lower-window
-    #:spec "%W" #:user-level 'expert)
+    #:spec "%W" #:class 'advanced)
   (define-command 'raise-window-depth raise-window-depth #:spec "%W")
   (define-command 'lower-window-depth lower-window-depth #:spec "%W")
 
-
 ;;; stacking groups of windows
 
   ;; Helper function for raise-windows and lower-windows. Calls (FIRST
@@ -407,7 +471,7 @@ lowest possible position. Otherwise raise it as far as allowed."
 	  (loop (delq lowest rest) (cons lowest out))))))
 
   (define (raise-lower-windows w order)
-    (if (or (eq (window-visibility w) 'unobscured)
+    (if (or (not (window-obscured w))
 	    (and (window-on-top-p (car order))
 		 ;; look for the group as a block.. this is a heuristic
 		 (let loop ((rest (memq (car order) (stacking-order))))
@@ -418,13 +482,18 @@ lowest possible position. Otherwise raise it as far as allowed."
 	(lower-windows w order)
       (raise-windows w order)))
 
-
 ;;; hooks
 
   ;; Called from the add-window-hook
   (define (stacking-add-window w)
     (unless (window-get w 'depth)
-      (window-put w 'depth 0)))
+      (let ((parents (transient-parents w)))
+	(if parents
+	    ;; put dialogs in at least as high a layer as their
+	    ;; highest parent, but never below the default depth
+	    (window-put w 'depth (apply max 0 (mapcar window-depth parents)))
+	  ;; default depth
+	  (window-put w 'depth 0)))))
 
   (add-hook 'add-window-hook stacking-add-window t)
   (add-hook 'after-add-window-hook restack-window t)
