@@ -1,5 +1,5 @@
 ;; gnome.jl -- minimal GNOME compliance
-;; $Id: gnome.jl,v 1.73 2001/07/24 04:37:14 jsh Exp $
+;; $Id: gnome.jl,v 1.77 2003/02/20 04:56:05 jsh Exp $
 
 ;; Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -32,7 +32,11 @@
 	    WIN_HINTS_SKIP_WINLIST
 	    WIN_HINTS_SKIP_TASKLIST
 	    WIN_HINTS_FOCUS_ON_CLICK
-	    WIN_HINTS_DO_NOT_COVER)
+	    WIN_HINTS_DO_NOT_COVER
+	    gnome-set-hint
+	    gnome-clear-hint
+	    gnome-toggle-hint
+	    gnome-hint-set-p)
 
     (open rep
 	  rep.regexp
@@ -85,6 +89,41 @@
       (setq vec (apply vector clients))
       (set-x-property 'root '_WIN_CLIENT_LIST vec 'CARDINAL 32)))
 
+  (define (gnome-set-hint w bit)
+    (let ((hints (get-x-property w '_WIN_HINTS)))
+      (if hints
+	  (setq hints (aref (nth 2 hints) 0))
+	(setq hints 0))
+      (setq hints (logior bit hints))
+      (set-x-property w '_WIN_HINTS (vector hints) 'CARDINAL 32)))
+
+  (define (gnome-clear-hint w bit)
+    (let ((hints (get-x-property w '_WIN_HINTS)))
+      (if hints
+	  (setq hints (aref (nth 2 hints) 0))
+	(setq hints 0))
+      (setq hints (logand (lognot bit) hints))
+      (set-x-property w '_WIN_HINTS (vector hints) 'CARDINAL 32)))
+
+  (define (gnome-toggle-hint w bit)
+    (let ((hints (get-x-property w '_WIN_HINTS)))
+      (if hints
+	  (setq hints (aref (nth 2 hints) 0))
+	(setq hints 0))
+      (setq hints (logxor bit hints))
+      (set-x-property w '_WIN_HINTS (vector hints) 'CARDINAL 32)))
+
+  ;; Queries whether a property in _WIN_HINTS is set.  Involves a
+  ;; server roundtrip as it does get-x-property.
+  (define (gnome-hint-set-p w bit)
+    (let ((hints (get-x-property w '_WIN_HINTS)))
+      (if hints
+	  (setq hints (aref (nth 2 hints) 0))
+	  (setq hints 0))
+      (if (zerop (logand bit hints))
+	  nil
+	  t)))
+
   (define current-workspace-index nil)
   (define current-workspace-count 0)
   (define current-workspace-names nil)
@@ -169,13 +208,17 @@
 		     0))))
       (mapc (lambda (state)
 	      (case state
-		((window-list-skip)
-		 (setq hints (logior (logand
-				      hints (lognot WIN_HINTS_SKIP_WINLIST))
-				     (if (window-get w 'window-list-skip)
-					 WIN_HINTS_SKIP_WINLIST 0)
-				     (if (window-get w 'avoid)
-					 WIN_HINTS_DO_NOT_COVER 0))))))
+		((window-list-skip task-list-skip)
+		 (setq hints (logior
+			      (logand
+			       hints (lognot (logior WIN_HINTS_SKIP_WINLIST
+						     WIN_HINTS_SKIP_TASKLIST)))
+			      (if (window-get w 'window-list-skip)
+				  WIN_HINTS_SKIP_WINLIST 0)
+			      (if (window-get w 'task-list-skip)
+				  WIN_HINTS_SKIP_TASKLIST 0)
+			      (if (window-get w 'avoid)
+				  WIN_HINTS_DO_NOT_COVER 0))))))
 	    states)
       (set-x-property w '_WIN_HINTS (vector hints) 'CARDINAL 32)))
 
@@ -185,19 +228,7 @@
       (when (and class (>= (length class) 2))
 	(cond ((and (string= (aref class 1) "Panel")
 		    (string= (aref class 0) "panel_window"))
-	       ;; XXX I don't think the GNOME hints specify these things...
-	       (window-put w 'focus-click-through t)
-	       (window-put w 'no-history t)
-	       (window-put w 'never-iconify t)
-	       (window-put w 'never-maximize t)
-	       ;; XXX the panel is broken, in that it doesn't check
-	       ;; XXX that the wm gave it the position that it wanted.
-	       ;; XXX (The wm is under no obligation; the panel should
-	       ;; XXX move itself to the required position after
-	       ;; XXX initially mapping the window, or perhaps it
-	       ;; XXX should use the USPosition hints?). The following
-	       ;; XXX line prevents panel windows being placed at all
-	       (window-put w 'placed t))
+	       (mark-window-as-dock w))
 	      ((string= (aref class 1) "gmc-desktop-icon")
 	       (window-put w 'focus-click-through t)
 	       (window-put w 'never-focus t)
@@ -237,6 +268,8 @@
 	  (window-put w 'cycle-skip t))
 	(unless (zerop (logand bits WIN_HINTS_SKIP_WINLIST))
 	  (window-put w 'window-list-skip t))
+	(unless (zerop (logand bits WIN_HINTS_SKIP_TASKLIST))
+	  (window-put w 'task-list-skip t))
 	(unless (zerop (logand bits WIN_HINTS_DO_NOT_COVER))
 	  (window-put w 'avoid t)))
       (when layer
@@ -287,6 +320,9 @@
 	     (unless (zerop (logand mask WIN_HINTS_SKIP_WINLIST))
 	       (window-put w 'window-list-skip
 			   (not (zerop (logand bits WIN_HINTS_SKIP_WINLIST)))))
+	     (unless (zerop (logand mask WIN_HINTS_SKIP_TASKLIST))
+	       (window-put w 'task-list-skip
+			   (not (zerop (logand bits WIN_HINTS_SKIP_TASKLIST)))))
 	     (unless (zerop (logand mask WIN_HINTS_DO_NOT_COVER))
 	       (window-put w 'avoid
 			   (not (zerop (logand bits WIN_HINTS_DO_NOT_COVER)))))))
@@ -346,7 +382,6 @@
 	       (proxy-current-event gnome-window-id (lsh 1 19))
 	       t)))))
 
-
 ;;; initialisation
 
   (define (gnome-init)
@@ -393,7 +428,8 @@
     (add-hook 'add-window-hook gnome-set-client-state)
     (call-after-state-changed '(sticky shaded maximized ignored stacking)
 			      gnome-set-client-state)
-    (call-after-state-changed '(window-list-skip) gnome-set-client-hints)
+    (call-after-state-changed '(window-list-skip task-list-skip)
+			      gnome-set-client-hints)
 
     (add-hook 'client-message-hook gnome-client-message-handler)
     (add-hook 'property-notify-hook gnome-property-handler)
@@ -411,7 +447,4 @@
 
   (unless (or gnome-window-id batch-mode)
     (gnome-init)
-    (require 'sawfish.wm.gnome.match-window))
-
-  (add-window-menu-toggle (_ "In GNOME _task list")
-			  'gnome-toggle-skip-tasklist))
+    (require 'sawfish.wm.gnome.match-window)))
