@@ -1,5 +1,5 @@
 ;; transient.jl -- support transient windows
-;; $Id: transient.jl,v 1.58 2001/02/06 20:56:16 jsh Exp $
+;; $Id: transient.jl,v 1.63 2002/04/27 19:31:25 jsh Exp $
 
 ;; Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -49,18 +49,9 @@
     :type boolean
     :group focus)
 
-  (defcustom transients-get-focus t
-    "Dialog windows inherit the focus from their parent."
-    :group focus
-    :type boolean)
+  (defvar decorate-transients nil
+    "Decorate dialog windows similarly to application windows.")
 
-  (defcustom decorate-transients nil
-    "Decorate dialog windows similarly to application windows."
-    :type boolean
-    :group appearance
-    :after-set after-setting-frame-option)
-
-
 ;;; functions
 
   (define (transient-of-p x y #!key allow-root)
@@ -124,7 +115,6 @@ indirect transients of the parent window in question."
 transient group as window W."
     (mapc fun (transient-group w)))
 
-
 ;;; commands for raising windows with their transients
 
   (define (raise-window-and-transients w)
@@ -144,38 +134,36 @@ the level of any transient windows it has."
     (raise-lower-windows w (transient-group w t)))
 
   (define-command 'raise-window-and-transients
-    raise-window-and-transients #:spec "%W" #:user-level 'expert)
+    raise-window-and-transients #:spec "%W" #:class 'advanced)
   (define-command 'lower-window-and-transients
-    lower-window-and-transients #:spec "%W" #:user-level 'expert)
+    lower-window-and-transients #:spec "%W" #:class 'advanced)
   (define-command 'raise-lower-window-and-transients
-    raise-lower-window-and-transients #:spec "%W" #:user-level 'expert)
+    raise-lower-window-and-transients #:spec "%W" #:class 'advanced)
 
-
 ;;; displaying
 
   (define (transient-frame-type w type)
     (if (and decorate-transients (window-transient-p w))
 	(case type
 	  ((transient) 'default)
-	  ((shaped-transient) 'shaped)
+	  ((shaded-transient) 'shaded)
 	  (t type))
       type))
 
   (define-frame-type-mapper transient-frame-type)
 
-
 ;;; hooks
 
   (define (transient-map-window w)
-    (cond ((and transients-get-focus
-		(window-transient-p w)
+    (cond ((and (window-transient-p w)
 		(window-really-wants-input-p w)
 		(window-visible-p w)
 		(input-focus)
 		(transient-of-p w (input-focus) #:allow-root t))
 	   (set-input-focus w))
 	  ((and (or (and focus-windows-when-mapped
-			 (not (window-get w 'never-focus)))
+			 (not (window-get w 'never-focus))
+			 (not (window-get w 'inhibit-focus-when-mapped)))
 		    (window-get w 'focus-when-mapped))
 		(or (not (window-transient-p w))
 		    (eql (window-transient-p w) (root-window-id)))
