@@ -56,14 +56,24 @@
   (defvar uniconify-to-current-viewport t
     "Windows uniconify to the current viewport.")
 
-
+  (defcustom scroll-viewport-steps 1
+    "Number of steps in which to scroll between viewports (less steps = faster scrolling)."
+    :group workspace
+    :type number
+    :range (1 . 50))
+
+  (defcustom viewport-boundary-mode 'stop
+    "Wether to stop or wrap-around on first/last viewport"
+     :group workspace
+    :type (choice wrap-around stop))
+
 ;;; raw viewport handling
 
   (defvar viewport-x-offset 0)
   (defvar viewport-y-offset 0)
 
-  (define (set-viewport x y)
-    ;; move W to its new position
+  (define (warp-viewport x y)
+    "Change view by incrementing the coordinates of the x,y position."
     (define (move-window w)
       (unless (window-get w 'sticky-viewport)
 	(let ((pos (window-position w)))
@@ -89,15 +99,26 @@
 	      (t (loop (cdr rest) (cons (car rest) inside) outside))))
 
       (setq viewport-x-offset x)
-      (setq viewport-y-offset y)
-      (call-hook 'viewport-moved-hook)))
+      (setq viewport-y-offset y)))
+
+  (define (set-viewport x y)
+    "Scroll viewport view by incrementing the coordinates of the x,y position.
+The scrolling makes a number of increments equal to `scroll-viewport-steps'."
+    (unless (= scroll-viewport-steps 1) ; fast skip if scroll is unwanted
+      (let* ((xstep (quotient (- x viewport-x-offset) scroll-viewport-steps))
+             (ystep (quotient (- y viewport-y-offset) scroll-viewport-steps))
+             (step-count (if (= xstep ystep 0) 0 scroll-viewport-steps)))
+        (while (> step-count 1)
+          (warp-viewport (+ viewport-x-offset xstep) (+ viewport-y-offset ystep))
+          (setq step-count (1- step-count)))))
+    (warp-viewport x y)
+    (call-hook 'viewport-moved-hook))
 
   (define (viewport-before-exiting)
     (set-screen-viewport 0 0))
 
   (add-hook 'before-exit-hook viewport-before-exiting t)
 
-
 ;; screen sized viewport handling
 
   (define (screen-viewport)
@@ -106,10 +127,13 @@
 
   ;; returns t if it actually moved the viewport
   (define (set-screen-viewport col row)
+    (when (eq viewport-boundary-mode 'wrap-around)
+      (setq col (mod col (car viewport-dimensions))
+            row (mod row (cdr viewport-dimensions))))
     (when (and (>= col 0) (< col (car viewport-dimensions))
-	       (>= row 0) (< row (cdr viewport-dimensions)))
+               (>= row 0) (< row (cdr viewport-dimensions)))
       (set-viewport (* col (screen-width))
-		    (* row (screen-height)))
+                    (* row (screen-height)))
       t))
 
   (define (select-workspace-and-viewport space col row)
@@ -202,7 +226,6 @@
     (setq viewport-dimensions (cons width height))
     (viewport-size-changed))
 
-
 ;; commands
 
   (define (activate-viewport x y)
@@ -296,7 +319,6 @@
   (define-command 'move-window-up move-window-up #:spec "%W" #:class 'viewport)
   (define-command 'move-window-down move-window-down #:spec "%W" #:class 'viewport)
 
-
 ;;; session management, config
 
   (define (viewport-saved-state w)
