@@ -39,6 +39,7 @@
 	     warp-cursor-to-window
 	     activate-window
 	     constrain-dimension-to-hints
+	     constrain-aspect-to-hints
 	     resize-window-with-hints
 	     resize-window-with-hints*
 	     window-gravity
@@ -102,7 +103,6 @@ means outside the left window edge.")
   (defvar dock-window-depth 0
     "The stacking depth of dock windows.")
 
-
 ;;; finding windows, reading properties
 
   (define (get-window-by-name name)
@@ -210,7 +210,6 @@ supported by client window W."
 		((eq (aref data i) atom) t)
 		(t (loop (1+ i))))))))
 
-
 ;;; warping
 
   (define (warp-cursor-to-window w #!optional x y)
@@ -247,7 +246,6 @@ specified by the user."
     (window-order-push w)
     (call-window-hook 'activate-window-hook w))
 
-
 ;;; resizing windows in accordance with their size hints
 
   (define (constrain-dimension-to-hints x dimension hints)
@@ -265,6 +263,13 @@ specified by the user."
 		   (+ (* (ceiling (/ (- x bottom) inc)) inc) bottom)))))
       (clamp x (or minimum base 1) maximum)))
 
+  (define (constrain-aspect-to-hints a old-b dimension min-aspect max-aspect)
+    (let ((min-ratio (/ (cadr min-aspect) (cddr min-aspect)))
+          (max-ratio (/ (cadr max-aspect) (cddr min-aspect))))
+      (if (eq dimension 'y)
+          (clamp old-b (floor (* a min-ratio)) (floor (* a max-ratio)))
+        (clamp old-b (floor (/ a max-ratio)) (floor (/ a min-ratio))))))
+
   (define (resize-window-with-hints w cols rows #!optional hints)
     "Resize window W to COLS x ROWS, using the window's size hints to define
 the row and column size, and the minimum possible size.
@@ -346,7 +351,6 @@ If HINTS is non-nil, then it is the size hints structure to use. Otherwise
 	  (adjust-position-for-gravity/y
 	   w grav (cdr coords) #:inverse unadjust)))
 
-
 ;;; deleting windows
 
   (define (delete-window w #!optional safely)
@@ -366,7 +370,6 @@ If HINTS is non-nil, then it is the size hints structure to use. Otherwise
 
   (define-command 'delete-window-safely delete-window-safely #:spec "%W")
 
-
 ;;; making window names unique
 
   (define (uniquify-name in existing)
@@ -390,7 +393,6 @@ string `uniquify-name-format' to generate unique names."
 
   (define-command 'uniquify-window-name uniquify-window-name #:spec "%W")
 
-
 ;; selecting a single window
 
   (define select-window-map
@@ -409,7 +411,6 @@ string `uniquify-name-format' to generate unique names."
 	      (recursive-edit)))
 	(ungrab-pointer))))
 
-
 ;;; avoided (i.e. non-overlapped) windows
 
   (define (window-avoided-p w)
@@ -429,7 +430,6 @@ returned in the list."
 		      (and (not (eq w window))
 			   (window-avoided-p w)))))
 
-
 ;;; property and window-state changed interface
 
   (define prop-changes '())
@@ -484,7 +484,6 @@ STATES has been changed. STATES may also be a single symbol."
 		 ((cdr cell) w relevant))))
 	    state-changes)))
 
-
 ;; gaollable functions
 
   (gaol-add window-really-wants-input-p window-class window-avoided-p
