@@ -1,5 +1,5 @@
 /* events.c -- Event handling
-   $Id: events.c 4244 2008-08-04 14:42:49Z jkozicki $
+   $Id: events.c 4301 2008-11-19 20:45:08Z chrisb $
 
    Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -269,7 +269,6 @@ install_colormaps (Lisp_Window *w)
     }
 }
 
-
 /* Individual event handlers */
 
 static void
@@ -445,6 +444,7 @@ motion_notify (XEvent *ev)
 {
     Window tmpw;
     int tmp;
+    unsigned tmpu;
     int x, y;
     
     /* Swallow any pending motion events as well. */
@@ -455,7 +455,7 @@ motion_notify (XEvent *ev)
        until the pointer's position has been queried. I should
        check the Xlib manuals about this. */
     if(XQueryPointer(dpy, ev->xmotion.window,
-		     &tmpw, &tmpw, &x, &y, &tmp, &tmp, (gpointer) &tmp))
+		     &tmpw, &tmpw, &x, &y, &tmp, &tmp, &tmpu))
     {
 	record_mouse_position (x, y, ev->type, ev->xmotion.window);
     }
@@ -483,7 +483,7 @@ update_window_name(Lisp_Window * w, XPropertyEvent xproperty) {
     unsigned char *prop;
     Atom actual;
     int format;
-    long nitems, bytes_after;
+    unsigned long nitems, bytes_after;
     char **text_list;
     XTextProperty tprop;
     int count;
@@ -491,10 +491,9 @@ update_window_name(Lisp_Window * w, XPropertyEvent xproperty) {
     int convert_status;
 
     if (xproperty.state != PropertyNewValue
-        || XGetWindowProperty (dpy, w->id, xproperty.atom,
-                               0, 200, False, AnyPropertyType, &actual,
-                               &format, (gpointer) &nitems,
-                               (gpointer) &bytes_after, &prop) != Success
+        || XGetWindowProperty (dpy, w->id, xproperty.atom, 0, 200, False,
+                               AnyPropertyType, &actual, &format, &nitems,
+                               &bytes_after, &prop) != Success
         || actual == None)
         return FALSE;
 
@@ -507,7 +506,7 @@ update_window_name(Lisp_Window * w, XPropertyEvent xproperty) {
     tprop.value = prop;
     tprop.encoding = actual;
     tprop.format = format;
-    tprop.nitems = strlen ((gpointer) prop);
+    tprop.nitems = strlen ((char *) prop);
 
 #ifdef X_HAVE_UTF8_STRING
     if (actual == xa_compound_text || actual == XA_STRING
@@ -528,8 +527,8 @@ update_window_name(Lisp_Window * w, XPropertyEvent xproperty) {
         {
             if (count > 0)
             {
-                char * utf8str = g_locale_to_utf8(text_list[0], -1,
-                                                  NULL, NULL, NULL);
+                char *utf8str = g_locale_to_utf8(text_list[0], -1,
+                                                 NULL, NULL, NULL);
                 if (utf8str)
                 {
                     str = rep_string_dup (utf8str);
@@ -1080,8 +1079,8 @@ focus_out (XEvent *ev)
 	    }
 	}
     }
-    else if ((w = x_find_window_by_id (ev->xunmap.window)) != 0
-	     && WINDOW_IS_GONE_P (w) && ev->xunmap.window == w->saved_id)
+    else if ((w = x_find_window_by_id (ev->xfocus.window)) != 0
+	     && WINDOW_IS_GONE_P (w) && ev->xfocus.window == w->saved_id)
     {
 	/* focus-out event from a deleted window */
 	if (focus_window == w)
@@ -1274,7 +1273,6 @@ shape_notify (XEvent *ev)
     }
 }
 
-
 
 static int synthetic_configure_mutex;
 
@@ -1351,7 +1349,7 @@ get_server_timestamp (void)
     while (XCheckWindowEvent (dpy, w, PropertyChangeMask, &ev)) ;
     XSelectInput (dpy, w, PropertyChangeMask | KeyPressMask);
     XChangeProperty (dpy, w, xa_sawmill_timestamp,
-		     XA_STRING, 8, PropModeReplace, (gpointer) "foo", 3);
+		     XA_STRING, 8, PropModeReplace, (unsigned char *)"foo", 3);
     XSelectInput (dpy, w, KeyPressMask);
     XWindowEvent (dpy, w, PropertyChangeMask, &ev);
 
@@ -1371,7 +1369,6 @@ ungrab_pointer (void)
     XUngrabPointer (dpy, last_event_time);
 }
 
-
 /* Window-local event handlers */
 
 /* Register that FUN should be called for any events received from
@@ -1401,7 +1398,6 @@ window_event_handler (Window w)
 			 &fun.p) ? 0 : fun.v;
 }
 
-
 /* Event loop */
 
 static repv
@@ -1498,7 +1494,6 @@ handle_sync_input (int fd)
     handle_input_mask (0);
 }
 
-
 /* Lisp functions */
 
 DEFUN("query-pointer", Fquery_pointer, Squery_pointer, (repv get), rep_Subr1) /*
@@ -1516,9 +1511,10 @@ the server, otherwise it's taken from the current event (if possible).
     {
 	Window tmpw;
 	int tmp;
+        unsigned tmpu;
 	int x, y;
 	if(XQueryPointer(dpy, root_window, &tmpw, &tmpw,
-			 &x, &y, &tmp, &tmp, (gpointer) &tmp))
+			 &x, &y, &tmp, &tmp, &tmpu))
 	{
 	    record_mouse_position (x, y, -1, 0);
 	}
@@ -1675,7 +1671,6 @@ DEFUN("clicked-frame-part", Fclicked_frame_part,
     return (clicked_frame_part != 0) ? rep_VAL (clicked_frame_part) : Qnil;
 }
 
-
 /* initialisation */
 
 void
