@@ -1,5 +1,5 @@
 /* fonts.c -- font manipulation
-   $Id: fonts.c 4244 2008-08-04 14:42:49Z jkozicki $
+   $Id: fonts.c 4301 2008-11-19 20:45:08Z chrisb $
 
    Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -72,12 +72,11 @@ struct Lisp_Font_Class_struct {
     const char *type;
     bool (*load) (Lisp_Font *f);
     void (*finalize) (Lisp_Font *f);
-    int (*measure) (Lisp_Font *f, unsigned char *string, size_t length);
-    void (*draw) (Lisp_Font *f, unsigned char *string, size_t length,
+    int (*measure) (Lisp_Font *f, char *string, size_t length);
+    void (*draw) (Lisp_Font *f, char *string, size_t length,
 		  Window id, GC gc, Lisp_Color *fg, int x, int y);
 };
 
-
 /* Xlib font structs */
 
 static bool
@@ -104,13 +103,13 @@ fontstruct_finalize (Lisp_Font *f)
 }
 
 static int
-fontstruct_measure (Lisp_Font *f, unsigned char *string, size_t length)
+fontstruct_measure (Lisp_Font *f, char *string, size_t length)
 {
-    return XTextWidth (f->font, (gpointer) string, length);
+    return XTextWidth (f->font, string, length);
 }
 
 static void
-fontstruct_draw (Lisp_Font *f, unsigned char *string, size_t length,
+fontstruct_draw (Lisp_Font *f, char *string, size_t length,
 		 Window id, GC gc, Lisp_Color *fg, int x, int y)
 {
     XFontStruct *fs;
@@ -122,7 +121,7 @@ fontstruct_draw (Lisp_Font *f, unsigned char *string, size_t length,
     gcv.font = fs->fid;
     XChangeGC (dpy, gc, GCForeground | GCFont, &gcv);
 
-    XDrawString (dpy, id, gc, x, y, (gpointer) string, length);
+    XDrawString (dpy, id, gc, x, y, string, length);
 }
 
 static const Lisp_Font_Class fontstruct_class = {
@@ -131,7 +130,6 @@ static const Lisp_Font_Class fontstruct_class = {
     fontstruct_measure, fontstruct_draw,
 };
 
-
 /* Xlib font sets */
 
 static char *
@@ -309,17 +307,17 @@ fontset_finalize (Lisp_Font *f)
 }
 
 static int
-fontset_measure (Lisp_Font *f, unsigned char *string, size_t length)
+fontset_measure (Lisp_Font *f, char *string, size_t length)
 {
 #ifdef X_HAVE_UTF8_STRING
-    return Xutf8TextEscapement (f->font, (gpointer) string, length);
+    return Xutf8TextEscapement (f->font, string, length);
 #else
     return XmbTextEscapement (f->font, string, length);
 #endif
 }
 
 static void
-fontset_draw (Lisp_Font *f, unsigned char *string, size_t length,
+fontset_draw (Lisp_Font *f, char *string, size_t length,
 	      Window id, GC gc, Lisp_Color *fg, int x, int y)
 {
     XGCValues gcv;
@@ -327,7 +325,7 @@ fontset_draw (Lisp_Font *f, unsigned char *string, size_t length,
     gcv.foreground = fg->pixel;
     XChangeGC (dpy, gc, GCForeground, &gcv);
 #ifdef X_HAVE_UTF8_STRING
-    Xutf8DrawString (dpy, id, f->font, gc, x, y, (gpointer) string, length);
+    Xutf8DrawString (dpy, id, f->font, gc, x, y, string, length);
 #else
     XmbDrawString (dpy, id, f->font, gc, x, y, string, length);
 #endif
@@ -339,7 +337,6 @@ static const Lisp_Font_Class fontset_class = {
     fontset_measure, fontset_draw,
 };
 
-
 /* Xft fonts */
 
 #ifdef HAVE_X11_XFT_XFT_H
@@ -368,17 +365,17 @@ xft_finalize (Lisp_Font *f)
 }
 
 static int
-xft_measure (Lisp_Font *f, unsigned char *string, size_t length)
+xft_measure (Lisp_Font *f, char *string, size_t length)
 {
     XGlyphInfo info;
 
-    XftTextExtentsUtf8 (dpy, f->font, string, length, &info);
+    XftTextExtentsUtf8 (dpy, f->font, (FcChar8 *)string, length, &info);
 
     return info.xOff; 
 }
 
 static void
-xft_draw (Lisp_Font *f, unsigned char *string, size_t length,
+xft_draw (Lisp_Font *f, char *string, size_t length,
 	  Window id, GC gc, Lisp_Color *fg, int x, int y)
 {
     static XftDraw *draw;
@@ -397,7 +394,7 @@ xft_draw (Lisp_Font *f, unsigned char *string, size_t length,
     xft_color.color.alpha = fg->alpha;
 
     XftDrawStringUtf8 (draw, &xft_color, f->font,
-		    x, y, string, length);
+                       x, y, (FcChar8 *)string, length);
 }
 
 static const Lisp_Font_Class xft_class = {
@@ -408,7 +405,6 @@ static const Lisp_Font_Class xft_class = {
 
 #endif /* HAVE_X11_XFT_XFT_H */
 
-
 /* Pango fonts */
 
 #ifdef HAVE_PANGO
@@ -485,14 +481,14 @@ pango_finalize (Lisp_Font *f)
 }
 
 static int
-pango_measure (Lisp_Font *f, unsigned char *string, size_t length)
+pango_measure (Lisp_Font *f, char *string, size_t length)
 {
     PangoLayout *layout;
     PangoRectangle rect;
 
     layout = pango_layout_new (pango_context);
     pango_layout_set_font_description(layout, f->font);
-    pango_layout_set_text (layout, (gpointer) string, length);
+    pango_layout_set_text (layout, string, length);
 
     pango_layout_get_extents (layout, NULL, &rect);
 
@@ -527,7 +523,7 @@ pango_draw_line (XftDraw *draw, Window id, GC gc, XftColor *xft_color,
 }
 
 static void
-pango_draw (Lisp_Font *f, unsigned char *string, size_t length,
+pango_draw (Lisp_Font *f, char *string, size_t length,
 	    Window id, GC gc, Lisp_Color *fg, int x, int y)
 {
     static XftDraw *draw;
@@ -548,7 +544,7 @@ pango_draw (Lisp_Font *f, unsigned char *string, size_t length,
 
     layout = pango_layout_new (pango_context);
     pango_layout_set_font_description(layout, f->font);
-    pango_layout_set_text (layout, (gpointer) string, length);
+    pango_layout_set_text (layout, string, length);
     iter = pango_layout_get_iter (layout);
 
     do {
@@ -572,7 +568,6 @@ static const Lisp_Font_Class pango_class = {
 
 #endif /* HAVE_PANGO */
 
-
 /* All classes */
 
 static const Lisp_Font_Class *classes[] = {
@@ -587,7 +582,6 @@ static const Lisp_Font_Class *classes[] = {
     0,
 };
 
-
 /* Entry points */
 
 DEFUN ("font-type-exists-p", Ffont_type_exists_p,
@@ -791,7 +785,7 @@ Return t if ARG is a font object.
 }
 
 int
-x_text_width (repv font, unsigned char *string, size_t len)
+x_text_width (repv font, char *string, size_t len)
 {
     return (*VFONT (font)->class->measure) (VFONT (font), string, len);
 }
@@ -799,7 +793,7 @@ x_text_width (repv font, unsigned char *string, size_t len)
 /* The foreground pixel of GC is undefined after this function returns. */
 void
 x_draw_string (Window id, repv font, GC gc, Lisp_Color *fg_color,
-	       int x, int y, unsigned char *string, size_t len)
+	       int x, int y, char *string, size_t len)
 {
     (*VFONT (font)->class->draw) (VFONT (font), string, len,
 				  id, gc, fg_color, x, y);
@@ -817,7 +811,7 @@ the text STRING using font object FONT (or the default-font).
     if (font == Qnil)
 	font = global_symbol_value (Qdefault_font);
     rep_DECLARE2(font, FONTP);
-    return rep_MAKE_INT (x_text_width (font, (gpointer) rep_STR(string),
+    return rep_MAKE_INT (x_text_width (font, rep_STR(string),
 				       rep_STRING_LEN(string)));
 }
 
@@ -863,7 +857,6 @@ default-font).
     return rep_MAKE_INT(VFONT(font)->descent);
 }
 
-
 /* type hooks */
 
 static int
@@ -921,7 +914,6 @@ use_xft (void)
     return val == NULL || strcmp (val, "0") != 0;
 }
 
-
 /* initialisation */
 
 void
