@@ -1,5 +1,5 @@
 /* frames.c -- window frame manipulation
-   $Id: frames.c 4244 2008-08-04 14:42:49Z jkozicki $
+   $Id: frames.c 4301 2008-11-19 20:45:08Z chrisb $
 
    Copyright (C) 1999, 2000 John Harper <john@dcs.warwick.ac.uk>
 
@@ -92,7 +92,6 @@ static repv state_syms[fps_MAX];
 static bool frame_draw_mutex;
 bool frame_state_mutex;
 
-
 /* type hooks */
 
 static struct frame_part *
@@ -183,7 +182,6 @@ fp_sweep (void)
     }
 }
 
-
 /* building frames from component lists
 
    build the frame from the list of components. Each element
@@ -722,7 +720,7 @@ set_frame_part_fg (struct frame_part *fp)
 		length = rep_STRING_LEN(result);
 	    }
 
-	    width = x_text_width (font, (gpointer) rep_STR(string), length);
+	    width = x_text_width (font, rep_STR(string), length);
 	    height = VFONT(font)->ascent + VFONT(font)->descent;
 	}
 
@@ -831,7 +829,7 @@ set_frame_part_fg (struct frame_part *fp)
 
 	    x_draw_string (fp->id, font, fp->gc, VCOLOR(fg),
 			   x, y + VFONT(font)->ascent,
-			   (gpointer) rep_STR(string), length);
+                           rep_STR(string), length);
 
 	    fp->drawn.text = string;
 	}
@@ -1692,7 +1690,6 @@ restack_frame_parts (Lisp_Window *w)
     }
 }
 
-
 /* creating window frames */
 
 /* Create a frame for window W. Called with the server grabbed. If
@@ -1734,7 +1731,6 @@ destroy_window_frame (Lisp_Window *w, bool leave_frame_win)
     }
 }
 
-
 /* Lisp functions */
 
 DEFUN("frame-draw-mutex", Fframe_draw_mutex,
@@ -1906,7 +1902,6 @@ DEFUN("refresh-window", Frefresh_window,
     return Qt;
 }
 
-
 /* initialisation */
 
 void
