@@ -1,5 +1,5 @@
 /* images.c -- Image handling
-   $Id: images.c 4244 2008-08-04 14:42:49Z jkozicki $
+   $Id: images.c 4301 2008-11-19 20:45:08Z chrisb $
 
    Copyright (C) 1999, 2000 John Harper <john@dcs.warwick.ac.uk>
 
@@ -171,7 +171,8 @@ find_image_file (repv file, bool *deletep)
 }
 
 Pixmap
-make_bitmap (repv file, int *widthp, int *heightp, int *x_hotp, int *y_hotp)
+make_bitmap (repv file, unsigned *widthp, unsigned *heightp,
+             int *x_hotp, int *y_hotp)
 {
     bool delete;
     file = find_image_file (file, &delete);
@@ -179,7 +180,7 @@ make_bitmap (repv file, int *widthp, int *heightp, int *x_hotp, int *y_hotp)
     {
 	Pixmap bitmap;
 	int ret = XReadBitmapFile (dpy, root_window, rep_STR(file),
-				   (gpointer) widthp, (gpointer) heightp, &bitmap, x_hotp, y_hotp);
+				   widthp, heightp, &bitmap, x_hotp, y_hotp);
 
 	if (delete)
 	    Fdelete_file (file);
@@ -227,7 +228,8 @@ make-image-from-x-drawable ID [MASK-ID]
    Drawable d;
    Pixmap mask = 0;
    Window root;
-   int x, y, w, h, bdr, dp;
+   int x, y;
+   unsigned w, h, bdr, dp;
    image_t im;
 
    rep_DECLARE1 (id, rep_INTP);
@@ -235,7 +237,7 @@ make-image-from-x-drawable ID [MASK-ID]
    if (rep_INTP (mask_id))
        mask = rep_INT (mask_id);
 
-   if (!XGetGeometry (dpy, d, &root, &x, &y, (gpointer) &w, (gpointer) &h, (gpointer) &bdr, (gpointer) &dp))
+   if (!XGetGeometry (dpy, d, &root, &x, &y, &w, &h, &bdr, &dp))
        return Qnil;
 
 #if defined HAVE_IMLIB
@@ -1186,7 +1188,6 @@ contents of IMAGE starting at position (X, Y).
 	return rep_mem_error ();
 }
 
-
 /* image structure accessors */
 
 int
@@ -1250,7 +1251,6 @@ image_changed (Lisp_Image *im)
 #endif
 }
 
-
 /* render functions */
 
 #if defined HAVE_GDK_PIXBUF
@@ -1480,7 +1480,6 @@ paste_image_to_drawable (Lisp_Image *img, Drawable d,
 #endif
 }
 
-
 /* lisp functions for accessing image contents */
 
 static repv
@@ -1688,7 +1687,6 @@ of the specified pixel to (as accepted by `image-set').
     return Qnil;
 }
 
-
 /* type hooks */
 
 static int
@@ -1742,7 +1740,6 @@ image_sweep (void)
     }
 }
 
-
 /* initialisation */
 
 void
