@@ -1,5 +1,5 @@
 /* keys.c -- Key binding and evaluating (this should be called events.c)
-   $Id: keys.c 4244 2008-08-04 14:42:49Z jkozicki $
+   $Id: keys.c 4301 2008-11-19 20:45:08Z chrisb $
 
    Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -103,7 +103,6 @@ static int all_buttons[9] = { Button1, Button2, Button3, Button4, Button5, Butto
 static int total_lock_combs, all_lock_mask;
 static int all_lock_combs[2*2*2];
 
-
 /* Translate from X events to Lisp events */
 
 static unsigned long
@@ -383,7 +382,6 @@ translate_event_to_x_button (repv ev, unsigned int *button, unsigned int *state)
     return 0;
 }
 
-
 /* Keymap searching */
 
 static inline bool
@@ -642,7 +640,6 @@ eval_input_event(repv context_map)
     return result;
 }
 
-
 /* Translate text->event and vice versa */
 
 struct key_def {
@@ -742,19 +739,19 @@ static struct key_def default_codes[] = {
 /* Puts the integers defining the event described in DESC into CODE
    and MODS. */
 static bool
-lookup_event(unsigned long *code, unsigned long *mods, unsigned char *desc)
+lookup_event(unsigned long *code, unsigned long *mods, char *desc)
 {
     char *tem;
     char buf[100];
     *code = *mods = 0;
 
     /* First handle all modifiers */
-    while(*desc && (tem = strchr((gpointer) desc + 1, '-')) != 0)
+    while(*desc && (tem = strchr(desc + 1, '-')) != 0)
     {
 	struct key_def *x = default_mods;
 
-	memcpy(buf, desc, tem - (char *)desc);
-	buf[tem - (char *)desc] = 0;
+	memcpy(buf, desc, tem - desc);
+	buf[tem - desc] = 0;
 
 	while(x->name != 0)
 	{
@@ -777,7 +774,7 @@ lookup_event(unsigned long *code, unsigned long *mods, unsigned char *desc)
 	unsigned int ks;
 	while(x->name != 0)
 	{
-	    if(strcasecmp((gpointer) desc, x->name) == 0)
+	    if(strcasecmp(desc, x->name) == 0)
 	    {
 		*mods |= x->mods;
 		*code = x->code;
@@ -793,7 +790,7 @@ lookup_event(unsigned long *code, unsigned long *mods, unsigned char *desc)
 	    }
 	    x++;
 	}
-	ks = XStringToKeysym((gpointer) desc);
+	ks = XStringToKeysym(desc);
 	if(ks != NoSymbol)
 	{
 	    if (*mods & ShiftMask)
@@ -822,14 +819,16 @@ error:
 
 /* Constructs the name of the event defined by CODE and MODS in BUF.  */
 static bool
-lookup_event_name(unsigned char *buf, unsigned long code, unsigned long mods)
+lookup_event_name(char *buf, unsigned long code, unsigned long mods)
 {
     int i;
     struct key_def *x;
     unsigned long type = mods & EV_TYPE_MASK;
+    char
+        *end = buf,
+        *tem;
 
-    char *end = (gpointer) buf, *tem;
-    *buf = 0;
+    *buf = '\0';
 
     mods &= EV_MOD_MASK;
     for(i = 32; i >= 0 && mods != 0; i--)	/* magic numbers!? */
@@ -878,8 +877,8 @@ bool
 print_event_prefix(void)
 {
     int i;
-    unsigned char buf[256];
-    unsigned char *bufp = buf;
+    char buf[256];
+    char *bufp = buf;
 
     if (next_keymap_path == rep_NULL)
 	return FALSE;
@@ -891,7 +890,7 @@ print_event_prefix(void)
     {
 	if (lookup_event_name (bufp, event_buf[i], event_buf[i+1]))
 	{
-	    bufp += strlen ((gpointer) bufp);
+	    bufp += strlen (bufp);
 	    *bufp++ = ' ';
 	}
     }
@@ -905,13 +904,12 @@ print_event_prefix(void)
     }
 
     rep_call_lisp1 (global_symbol_value (Qdisplay_message),
-		    rep_string_dupn ((gpointer) buf, bufp - buf));
+		    rep_string_dupn (buf, bufp - buf));
     printed_this_prefix = TRUE;
 
     return TRUE;
 }
 
-
 /* Lisp functions */
 
 DEFUN("make-keymap", Fmake_keymap, Smake_keymap, (void), rep_Subr0) /*
@@ -949,7 +947,7 @@ Returns KEYMAP when successful.
 	args = rep_CDR(args);
 	if (rep_STRINGP(arg1))
 	{
-	    if (!lookup_event (&code, &mods, (gpointer) rep_STR(arg1)))
+	    if (!lookup_event (&code, &mods, rep_STR(arg1)))
 		return Fsignal (Qbad_event_desc, rep_LIST_1(arg1));
 	}
 	else if(Feventp(arg1) != Qnil)
@@ -996,7 +994,7 @@ unbind-keys KEY-MAP EVENT-DESCRIPTION...
 	arg1 = rep_CAR(args);
 	if (rep_STRINGP(arg1))
 	{
-	    if (!lookup_event (&code, &mods, (gpointer) rep_STR(arg1)))
+	    if (!lookup_event (&code, &mods, rep_STR(arg1)))
 		return Fsignal (Qbad_event_desc, rep_LIST_1(arg1));
 	}
 	else if(Feventp(arg1) != Qnil)
@@ -1066,16 +1064,16 @@ a Lisp function hadn't been called instead.
 ::end:: */
 {
     KeySym ks;
-    unsigned char buf[256];
+    char buf[256];
     int len;
 
     if(current_x_event == 0)
 	return Fsignal(Qerror, rep_LIST_1(rep_VAL(&not_in_handler)));
 
     len = XLookupString(&current_x_event->xkey,
-			 (gpointer) buf, sizeof (buf) - 1, &ks, NULL);
+                        buf, sizeof (buf) - 1, &ks, NULL);
     if(len > 0)
-	return rep_string_dupn((gpointer) buf, len);
+	return rep_string_dupn(buf, len);
     else
 	return rep_null_string();
 }
@@ -1172,14 +1170,14 @@ event-name EVENT
 Returns a string naming the event EVENT.
 ::end:: */
 {
-    unsigned char buf[256];
+    char buf[256];
     if(!EVENTP(ev))
 	return rep_signal_arg_error(ev, 1);
 
     if(lookup_event_name(buf, rep_INT(EVENT_CODE(ev)),
 			 rep_INT(EVENT_MODS(ev))))
     {
-	return rep_string_dup((gpointer) buf);
+	return rep_string_dup(buf);
     }
     else
 	return Qnil;
@@ -1195,7 +1193,7 @@ Return the event whose name is EVENT-NAME.
     unsigned long code, mods;
     rep_DECLARE1(name, rep_STRINGP);
 
-    if(lookup_event(&code, &mods, (gpointer) rep_STR(name)))
+    if(lookup_event(&code, &mods, rep_STR(name)))
 	return MAKE_EVENT(rep_MAKE_INT(code), rep_MAKE_INT(mods));
     else
 	return Qnil;
@@ -1455,7 +1453,6 @@ synthesize-event EVENT WINDOW [PROPAGATE]
     return Qt;
 }
 
-
 /* Find the lisp modifier mask used by the meta and alt keys. This code
    shamelessly stolen from Emacs 19. :-) */
 
@@ -1655,7 +1652,6 @@ Returns the current value of the `Window Manager' modifier, an integer.
     return rep_MAKE_INT (wm_mod);
 }
 
-
 /* Key and button grabbing */
 
 static void
@@ -1854,7 +1850,6 @@ keymap_prop_change (Lisp_Window *w, repv prop, repv old, repv new)
     }
 }
 
-
 /* initialisation */
 
 void
