@@ -1,5 +1,5 @@
 /* libclient.c -- shared code for client program to communicate with server
-   $Id: libclient.c 4244 2008-08-04 14:42:49Z jkozicki $
+   $Id: libclient.c 4301 2008-11-19 20:45:08Z chrisb $
 
    Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -61,13 +61,12 @@ static char * (*eval_fun)(char *form, int *lenp, int *errorp);
 
 #define PROTOCOL_X11_VERSION 1
 
-
 
 /* copied from src/unix_main.c */
 static char *
 system_name(void)
 {
-    unsigned char buf[256];
+    char buf[256];
     struct hostent *h;
 
     static char *system_name;
@@ -75,7 +74,7 @@ system_name(void)
 	return system_name;
 
 #ifdef HAVE_GETHOSTNAME
-    if(gethostname((gpointer) buf, 256))
+    if(gethostname(buf, 256))
 	return rep_NULL;
 #else
     {
@@ -84,7 +83,7 @@ system_name(void)
 	strncpy(buf, uts.nodename, 256);
     }
 #endif
-    h = gethostbyname((gpointer) buf);
+    h = gethostbyname(buf);
     if(h)
     {
 	if(!strchr(h->h_name, '.'))
@@ -100,7 +99,7 @@ system_name(void)
 	    system_name = strdup(h->h_name);
     }
     else
-	system_name = strdup((gpointer) buf);
+	system_name = strdup(buf);
     return system_name;
 }
 
@@ -189,7 +188,6 @@ user_login_name (void)
     return tmp;
 }
 
-
 /* using the X based server io */
 
 Atom xa_sawfish_request, xa_sawfish_request_win;
@@ -203,8 +201,8 @@ net_server_eval (char *form, int *lenp, int *errorp)
     unsigned long nitems;
     XEvent ev;
 
-    XChangeProperty (dpy, portal, xa_sawfish_request, XA_STRING,
-		     8, PropModeReplace, (gpointer) form, strlen (form));
+    XChangeProperty (dpy, portal, xa_sawfish_request, XA_STRING, 8,
+                     PropModeReplace, (unsigned char *) form, strlen (form));
     /* swallow the event created by the above */
     XWindowEvent (dpy, portal, PropertyChangeMask, &ev);
 
@@ -300,7 +298,6 @@ net_server_init (char *display)
     return 0;
 }
 
-
 /* unix domain socket server */
 
 #ifdef HAVE_UNIX
@@ -412,7 +409,6 @@ unix_server_init (char *display)
 
 #endif /* HAVE_UNIX */
 
-
 /* entry points */
 
 int
