@@ -1,5 +1,5 @@
 /* server.h -- Definitions for client/server
-   $Id: server.h,v 1.6 1999/10/22 19:44:37 john Exp $
+   $Id: server.h 2922 2000-08-13 20:31:32Z john $
 
    Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -24,7 +24,7 @@
 
 /* Directory containing the unix domain sockets, each socket is
    simply the canonical display name */
-#define SAWMILL_SOCK_DIR "/tmp/.sawmill-%s"
+#define SAWMILL_SOCK_DIR "/tmp/.sawfish-%s"
 
 /* Types of request packet. A byte with one of these values is sent to
    initiate a command. */
