@@ -1,5 +1,5 @@
 /* windows.c -- window manipulation
-   $Id: windows.c 4261 2008-08-05 20:28:11Z tkorvola $
+   $Id: windows.c 4301 2008-11-19 20:45:08Z chrisb $
 
    Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -80,16 +80,16 @@ DEFSYM(south_east, "south-east");
 
 static repv gravity_map[StaticGravity+1];
 
-// In sawfish-1.3.3, the only callback used is keymap_prop_change. 
+/* In sawfish-1.3.3, the only callback used is keymap_prop_change. */
+
+static struct prop_handler *prop_handlers;
+
 struct prop_handler {
     struct prop_handler *next;
     repv prop;
     void (*callback) (Lisp_Window *w, repv prop, repv old, repv new);
 };
 
-static struct prop_handler *prop_handlers;
-
-
 /* utilities */
 
 /* Returns true if we should manage window ID */
@@ -228,10 +228,10 @@ void
 get_window_protocols (Lisp_Window *w)
 {
     Atom *prot;
-    unsigned int n;
+    int n;
     w->does_wm_take_focus = 0;
     w->does_wm_delete_window = 0;
-    if (XGetWMProtocols (dpy, w->id, &prot, (gpointer) &n) != 0)
+    if (XGetWMProtocols (dpy, w->id, &prot, &n) != 0)
     {
 	int i;
 	for (i = 0; i < n; i++)
@@ -271,7 +271,6 @@ after_local_map (Lisp_Window *w)
     Fungrab_server ();
 }
 
-
 /* manipulating the Lisp window structures */
 
 /* Return the window object containing ID, or a null pointer */
@@ -367,7 +366,7 @@ text_prop_to_utf8 (XTextProperty *prop)
     {
         char **list;
         int count;
-        prop->nitems = strlen((gpointer) prop->value);
+        prop->nitems = strlen((char *) prop->value);
 #ifdef X_HAVE_UTF8_STRING
         if (Xutf8TextPropertyToTextList (dpy, prop, &list, &count) >= Success)
         {
@@ -635,7 +634,6 @@ emit_pending_destroys (void)
     pending_destroys = 0;
 }
 
-
 /* Lisp functions */
 
 DEFUN("window-get", Fwindow_get, Swindow_get,
@@ -1396,7 +1394,7 @@ WINDOW. Returns the symbol `nil' if no such image.
        {
 	   Atom actual_type;
 	   int actual_format;
-	   long nitems, bytes_after;
+	   unsigned long nitems, bytes_after;
 	   union {
 	       unsigned long *l;
 	       unsigned char *c;
@@ -1411,7 +1409,7 @@ WINDOW. Returns the symbol `nil' if no such image.
 	   if (XGetWindowProperty (dpy, VWIN (win)->id, kwm_win_icon,
 				   0, 2, False, kwm_win_icon,
 				   &actual_type, &actual_format,
-				   (gpointer) &nitems, (gpointer) &bytes_after,
+				   &nitems, &bytes_after,
 				   &data.c) == Success
 	       && actual_type == kwm_win_icon
 	       && bytes_after == 0)
@@ -1497,7 +1495,6 @@ Return the list of windows that match the predicate function PRED.
     return output;
 }
 
-
 /* type hooks */
 
 static int
@@ -1569,7 +1566,6 @@ window_sweep (void)
     }
 }
 
-
 /* initialisation */
 
 void
