@@ -1,5 +1,5 @@
 /* x.c -- raw X manipulation
-   $Id: x.c 4244 2008-08-04 14:42:49Z jkozicki $
+   $Id: x.c 4301 2008-11-19 20:45:08Z chrisb $
 
    Copyright (C) 2000 John Harper <john@dcs.warwick.ac.uk>
 
@@ -222,7 +222,6 @@ x_function_from_sym (repv sym)
     return GXcopy;
 }
 
-
 /* GC Functions */
 
 static long
@@ -515,7 +514,6 @@ Return t if ARG is a X-GC object.
     return X_GCP (gc) ? Qt : Qnil;
 }
 
-
 /* Window functions */
 
 static long
@@ -993,7 +991,6 @@ DEFUN ("x-window-swap-buffers", Fx_window_swap_buffers,
     return Qt;
 }
 
-
 /* Drawing functions */
 
 DEFUN ("x-clear-window", Fx_clear_window,
@@ -1023,12 +1020,12 @@ specified font in the window associated with WINDOW.
     Drawable id = drawable_from_arg (window);
     int x = 0;
     int y = 0;
-    unsigned char *str;
+    char *str;
 
     rep_DECLARE (1, window, id != 0);
     rep_DECLARE (2, gc, X_VALID_GCP (gc, id));
     rep_DECLARE (3, xy, rep_CONSP (xy)
-		 && rep_INTP (rep_CAR (xy)) && rep_INTP (rep_CDR (xy)));
+                 && rep_INTP (rep_CAR (xy)) && rep_INTP (rep_CDR (xy)));
     rep_DECLARE4 (string, rep_STRINGP);
     if (font == Qnil)
 	font = global_symbol_value (Qdefault_font);
@@ -1036,10 +1033,10 @@ specified font in the window associated with WINDOW.
 
     x = rep_INT (rep_CAR (xy));
     y = rep_INT (rep_CDR (xy));
-    str = (gpointer) rep_STR (string);
+    str = rep_STR (string);
 
     x_draw_string (id, font, VX_GC (gc)->gc,
-		   &VX_GC (gc)->fg_copy, x, y, str, strlen ((gpointer) str));
+                   &VX_GC (gc)->fg_copy, x, y, str, strlen (str));
     return Qt;
 }
 
@@ -1340,7 +1337,6 @@ DEFUN ("x-grab-image-from-drawable", Fx_grab_image_from_drawable,
 					m == 0 ? Qnil : rep_MAKE_INT (m));
 }
 
-
 /* Utility functions */
 
 DEFUN ("x-gc-set-dashes", Fx_gc_set_dashes, Sx_gc_set_dashes,
@@ -1394,7 +1390,6 @@ the offset.
     return Qt;
 }
 
-
 /* gc type hooks */
 
 static int
@@ -1440,7 +1435,6 @@ x_gc_sweep (void)
     }
 }
 
-
 /* window type hooks */
 
 static int
@@ -1487,7 +1481,6 @@ x_window_sweep (void)
     }
 }
 
-
 /* initialisation */
 
 repv
